import { HttpException, HttpStatus, Injectable, NotFoundException } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { HomePageCommonBannerCmsRepository } from "./home-page-common-banner-cms.repository";
import { UpdateHomePageCommonBannerCmsDto } from "./dto/update-home-page-common-banner-cms.dto";
import { HomePageCommonBannerCms } from "./entities/home-page-common-banner-cms.entity";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";

@Injectable()
export class HomePageCommonBannerCmsService {
    constructor(
      @InjectRepository(HomePageCommonBannerCmsRepository)
      private readonly repository: HomePageCommonBannerCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateHomePageCommonBannerCmsDto,
      files: {
          image: UploadedMulterFileI,
      }
    ): Promise<HomePageCommonBannerCms | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "HomePageCommonBannerCms/");
            dto.image = image;
        }
        let isImageOrColor: any = dto.isImageOrColor;
        if (isImageOrColor === "true") {
            dto.isImageOrColor = true;
        } else {
            dto.isImageOrColor = false;
        }
        const isExists = await this.repository.find({ isDeleted: false });
        // const isDefault: any = dto.isDefault;
        // dto.isDefault = isDefault === 'true';
        // if (dto.isDefault) {
        //     // Retrieve all entities
        //     const entities = await this.repository.find();

        //     // Update the isDefault property for each entity
        //     for (const entity of entities) {
        //         const updateData = await this.repository.update(entity.id, { isDefault: false });
        //     }
        //     ;
        // }
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new NotFoundException(Constants.NOT_FOUND);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageCommonBannerCms[] | Error> {
        const data = await this.repository.find({
            // stateCode: stateCode,
            isDeleted: false
        });
        if (!data) {
            throw new NotFoundException(Constants.NOT_FOUND);
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}