import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../../SpacesModule/SpacesService";
import { OfferPopupCmsService } from "./offer-popup-cms.service";
import { UpdateOfferPopupCmsDto } from "./dto/update-offer-popup-cms.dto";

@Controller({ path: "offer-popup-cms", version: Constants.API_VERSION_1 })

export class OfferPopupCmsController {
    constructor(private readonly service: OfferPopupCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateOfferPopupCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll(@Query("stateCode") stateCode: string) {
        return this.service.findAll(stateCode);
    }
}
