import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { DoSpacesService } from "../SpacesModule/SpacesService/doSpacesService";
import { BenefitsSectionLearnMoreRepository } from "./benefits-section-learn-more.repository";
import { CreateBenefitsSectionLearnMoreDto } from "./dto/create-benefits-section-learn-more.dto";
import { UpdateBenefitsSectionLearnMoreDto } from "./dto/update-benefits-section-learn-more.dto";
import { BenefitsSectionLearnMoreEntity } from "./entities/benefits-section-learn-more.entity";

@Injectable()
export class BenefitsSectionLearnMoreService {
    constructor(
      @InjectRepository(BenefitsSectionLearnMoreRepository)
      private readonly repository: BenefitsSectionLearnMoreRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(dto: CreateBenefitsSectionLearnMoreDto, files: {
        image: UploadedMulterFileI,
    }): Promise<BenefitsSectionLearnMoreEntity | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "BenefitsSectionLearnMore/");
            dto.image = image;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
    }

    async update(
      id: string,
      dto: UpdateBenefitsSectionLearnMoreDto,
      files: {
          image: UploadedMulterFileI,
      }
    ): Promise<BenefitsSectionLearnMoreEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "BenefitsSectionLearnMore/");
            dto.image = image;
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async findAll(): Promise<BenefitsSectionLearnMoreEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<BenefitsSectionLearnMoreEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({ benefitsId: id });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
