import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { urlSlug } from "src/helper/common-helper";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { DoSpacesService } from "../SpacesModule/SpacesService/doSpacesService";
import { CareerDepartmentRepository } from "./career-department.repository";
import { CreateCareerDepartmentDto } from "./dto/create-career-department.dto";
import { UpdateCareerDepartmentDto } from "./dto/update-career-department.dto";
import { CareerDepartment } from "./entities/career-department.entity";

@Injectable()
export class CareerDepartmentService {
    constructor(
      @InjectRepository(CareerDepartmentRepository)
      private readonly repository: CareerDepartmentRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(dto: CreateCareerDepartmentDto, files: {
        logo: UploadedMulterFileI
    }): Promise<CareerDepartment | Error> {
        if (files && files.logo) {
            const logo: any = await this.doSpaceService.uploadFile(files.logo[0], "CareerDepartment/");
            dto.logo = logo;
        }
        let slug = urlSlug(dto.name);
        dto.urlSlug = slug;
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async update(
      id: string,
      dto: UpdateCareerDepartmentDto,
      files: {
          logo: UploadedMulterFileI
      }
    ): Promise<CareerDepartment | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        if (files && files.logo) {
            const logo: any = await this.doSpaceService.uploadFile(files.logo[0], "CareerDepartment/");
            dto.logo = logo;
        }
        let slug = urlSlug(dto.name);
        dto.urlSlug = slug;
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }

    async findAll(): Promise<CareerDepartment[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<CareerDepartment[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully!");
    }
}
