import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CareerRepository } from "./career.repository";
import { CreateCareerDto } from "./dto/create-career.dto";
import { UpdateCareerDto } from "./dto/update-career.dto";
import { Career } from "./entities/career.entity";
import { getManager } from "typeorm";

@Injectable()
export class CareerService {
    constructor(
      @InjectRepository(CareerRepository)
      private readonly repository: CareerRepository
    ) {
    }

    async create(dto: CreateCareerDto): Promise<Career | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
    }

    async update(id: string, dto: UpdateCareerDto): Promise<Career | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async findAll(): Promise<Career[] | Error> {
        try {
            const data = await this.repository.findByFilterQuery({});

            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(
              200,
              "Data fetched successfully",
              "data", data
            );
        } catch (e) {
            return e;
        }
    }

    async filterData(
      sortBy: any,
      city?: any,
      state?: any,
      jobType?: any,
      store?: any
    ): Promise<Career[] | Error> {
        try {
            let whereQuery: any = ``;
            let orderByQuery: any = ``;

            if (sortBy === "'End Date") {
                orderByQuery = `ORDER BY c.createdAt DESC `;
            }

            if (sortBy === "Job Title") {
                orderByQuery = `ORDER BY c.title ASC`;
            }

            if (sortBy === "City") {
                orderByQuery = `ORDER BY c.city ASC`;
            }

            if (sortBy === "Employment Type") {
                orderByQuery = `ORDER BY c.jobType ASC`;
            }

            if (city) {
                if (whereQuery.length > 3) {
                    whereQuery += ` and c.city = '${city}' `;
                } else {
                    whereQuery += ` c.city = '${city}' `;
                }

            }

            if (state) {
                if (whereQuery.length > 3) {
                    whereQuery += ` and c.state = '${state}' `;
                } else {
                    whereQuery += ` c.state = '${state}' `;
                }
            }

            if (jobType) {
                if (whereQuery.length > 3) {
                    whereQuery += ` and c.jobType = '${jobType}' `;
                } else {
                    whereQuery += ` c.jobType = '${jobType}' `;
                }
            }

            if (store) {
                if (whereQuery.length > 3) {
                    whereQuery += ` and c.storeName = '${store}' `;
                } else {
                    whereQuery += ` c.storeName = '${store}' `;
                }
            }


            if (whereQuery.length > 3) {
                whereQuery += ` and c.isDeleted=0 `;
            } else {
                whereQuery += ` c.isDeleted=0 `;
            }

            if (whereQuery.substring(0, 3) === "and") {
                whereQuery = whereQuery.slice(4, whereQuery.length);
            }

            let conditionQuery: string;

            if (!whereQuery) {
                conditionQuery = ``;
            } else {
                conditionQuery = ` WHERE ${whereQuery} `;
            }

            let sql = `SELECT c.* FROM career as c
            ${conditionQuery} GROUP BY c.id  ${orderByQuery};`;

            console.log(sql);
            const entityManager = getManager();
            const data = await entityManager.query(sql);
            return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
        } catch (e) {
            return e;
        }
    }

    async findOne(id: string): Promise<Career[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
