import { EntityRepository, Repository } from "typeorm";
import { UpdateAboutPageUiDto } from "./dto/update-about-page-ui.dto";
import { AboutPageUI } from "./entities/about-page-ui.entity";

@EntityRepository(AboutPageUI)
export class AboutPageUiRepository extends Repository<AboutPageUI> {

    async createEntity(dto: UpdateAboutPageUiDto): Promise<AboutPageUI | Error> {
        try {
            const entity = this.create({
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor,
                backgroundColor: dto.backgroundColor,
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateAboutPageUiDto, id: string): Promise<AboutPageUI | Error> {
        try {
            await this.update(id, {
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor,
                backgroundColor: dto.backgroundColor,
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<AboutPageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}