import { Body, Controller, Delete, Get, Param, Patch, Post, Query, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { ContactReasonService } from "./contact-reason.service";
import { CreateContactReasonDto } from "./dto/create-contact-reason.dto";
import { UpdateContactReasonDto } from "./dto/update-contact-reason.dto";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";

@Controller({ path: "contact-reason", version: Constants.API_VERSION_1 })

export class ContactReasonController {
    constructor(private readonly service: ContactReasonService) {
    }

    @Post("/make-default")
    makeDefault(@Body() dto: any) {
        return this.service.makeDefault(dto);
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateContactReasonDto) {
        return this.service.create(dto);
    }

    @Get()
    findAll(@Query("stateCode") stateCode: string) {
        return this.service.findAll(stateCode);
    }

    @Get('/all')
    findAllContactReason(@Query("stateCode") stateCode: string) {
        return this.service.findAllContactReason(stateCode);
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/is-show/:id")
    @UseGuards(AdminAuthGuard)
    isShow(
        @Param("id") id: string,
        @Body() dto: any,
    ) {
        return this.service.isShow(id, dto);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateContactReasonDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
