import { Body, Controller, Get, Param, Patch, Post, Query, UseGuards } from "@nestjs/common";
import { StateWiseProductCategoryService } from "./state-wise-product-category.service";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";

@Controller({ path: "state-wise-product-category", version: Constants.API_VERSION_1 })

export class StateWiseProductCategoryController {
    constructor(private readonly service: StateWiseProductCategoryService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    createStateWiseCategory(@Body() dto: any) {
        return this.service.createStateWiseCategory(dto);
    }

    @Post("/position")
    @UseGuards(AdminAuthGuard)
    dragDropCategoryPosition(@Body() dto: any) {
        return this.service.dragDropCategoryPosition(dto);
    }

    @Post("/make-default")
    makeDefault(@Body() dto: any) {
        return this.service.makeDefault(dto);
    }

    @Get('/all')
    // @UseGuards(AdminAuthGuard)
    stateWiseAll(@Query("stateCode") stateCode: string){
        return this.service.stateWiseAll(stateCode);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(@Query("stateCode") stateCode: string){
        return this.service.findAll(stateCode);
    }

    @Patch(":id")
    @UseGuards(AdminAuthGuard)
    update(
        @Param("id") id: string,
        @Body() dto: any,
    ) {
        return this.service.update(id, dto);
    }
}
