import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { CreateHomePageSectionOneDto } from "./dto/create-home-page-section-one.dto";
import { UpdateHomePageSectionOneDto } from "./dto/update-home-page-section-one.dto";
import { HomePageSectionOneService } from "./home-page-section-one.service";

@Controller({ path: "home-page-section-one", version: Constants.API_VERSION_1 })

export class HomePageSectionOneController {
    constructor(private readonly service: HomePageSectionOneService) {
    }

    // @Post("/make-default")
    // makeDefault(@Body() dto: any) {
    //     return this.service.makeDefault(dto);
    // }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "openNowButtonFile", maxCount: 1 },
            { name: "mobileImage", maxCount: 1 },
        ]
    ))
    create(@Body() dto: CreateHomePageSectionOneDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI,
            openNowButtonFile: UploadedMulterFileI,
            mobileImage: UploadedMulterFileI
        }) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    // findAll(@Query("stateCode") stateCode: string)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "openNowButtonFile", maxCount: 1 },
            { name: "mobileImage", maxCount: 1 }
        ]
    ))
    update(
        @Param("id") id: string,
        @Body() dto: UpdateHomePageSectionOneDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI,
            openNowButtonFile: UploadedMulterFileI,
            mobileImage: UploadedMulterFileI
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
