import { Injectable } from "@nestjs/common";
import axios from "axios";
import { iHeartJaneMenuAPIAuthentication } from "src/helper/iheartjane-client-helper";
import { ResponseUtils } from "src/utils/response.utils";

@Injectable()
export class CartServiceIHeartJaneService {


    async createCart(variables: any) {
        try {
            const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/carts_api/v1/carts`;
            const config = {
                headers: {
                    "Content-Type": "application/json"
                }
            };
            const data = {
                store_id: variables?.retailerId
            }
            const response = await axios.post(apiUrl, data, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            return e;
        }
    }

    async addItemToCheckout(variables: any) {
        try {
            const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/carts_api/v1/carts/${variables?.checkoutId}/items`;
            const config = {
                headers: {
                    "Content-Type": "application/json"
                }
            };
            const data = {
                pvid: variables?.pvid,
                quantity: variables?.quantity
            }
            const response = await axios.post(apiUrl, data, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            return e;
        }
    }

    async removeItemFromCheckout(variables: any) {
        try {
            const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/carts_api/v1/carts/${variables?.checkoutId}/items/${variables?.pvid}`;
            const config = {
                headers: {
                    "Content-Type": "application/json"
                }
            }
            const response = await axios.delete(apiUrl, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            return e;
        }
    }


    async updateQuantity(variables: any) {
        try {
            const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/carts_api/v1/carts/${variables?.checkoutId}/items/${variables?.pvid}`;
            const config = {
                headers: {
                    "Content-Type": "application/json"
                }
            };
            const data = {
                quantity: variables?.quantity
            }
            const response = await axios.put(apiUrl, data, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            return e;
        }
    }

    public async getProduct(products: {}, store_id: string): Promise<any | Error> {
        try {
            const authentication: any = await iHeartJaneMenuAPIAuthentication();
            if (authentication.access_token) {
                const config = {
                    headers: {
                        "Content-Type": "application/json",
                        "Authorization": `Bearer ${authentication.access_token}`
                    }
                };

                const cartItems = Object.keys(products).map(async (item) => {
                    const productId = item?.split("+")[0]
                    const product = await axios.get(`${process.env.IHEARTJANE_API_HOST}/api/roots/menu_api/v1/stores/${store_id}/products/${productId}`
                        , config)
                    const data = product?.data?.data?.menu_product;
                    return data
                })
                return cartItems
            }
        } catch (error) {
            return error;
        }
    }

    public selectedVarient = (product, variantId) => {
        let tempVariantArr = [];
        (product.price_eighth_ounce && tempVariantArr.push({ weight: '8oz', priceId: 'eighth_ounce', price_eighth_ounce: product.price_eighth_ounce, discounted_price_eighth_ounce: product.discounted_price_eighth_ounce, max_cart_quantity_eighth_ounce: product.max_cart_quantity_eighth_ounce, special_price_eighth_ounce: product.special_price_eighth_ounce }));

        (product.price_gram && tempVariantArr.push({ weight: '1g', priceId: 'gram', price_gram: product.price_gram, discounted_price_gram: product.discounted_price_gram, max_cart_quantity_gram: product.max_cart_quantity_gram, special_price_gram: product.special_price_gram }));

        (product.price_half_gram && tempVariantArr.push({ weight: '0.5g', priceId: 'half_gram', price_half_gram: product.price_half_gram, discounted_price_half_gram: product.discounted_price_half_gram, max_cart_quantity_half_gram: product.max_cart_quantity_half_gram, special_price_half_gram: product.special_price_half_gram }));

        (product.price_half_ounce && tempVariantArr.push({ weight: '0.5oz', priceId: 'half_ounce', price_half_ounce: product.price_half_ounce, discounted_price_half_ounce: product.discounted_price_half_ounce, max_cart_quantity_half_ounce: product.max_cart_quantity_half_ounce, special_price_half_ounce: product.special_price_half_ounce }));

        (product.price_ounce && tempVariantArr.push({ weight: '1oz', priceId: 'ounce', price_ounce: product.price_ounce, discounted_price_ounce: product.discounted_price_ounce, max_cart_quantity_ounce: product.max_cart_quantity_ounce, special_price_ounce: product.special_price_ounce }));

        (product.price_quarter_ounce && tempVariantArr.push({ weight: '0.25oz', priceId: 'quarter_ounce', price_quarter_ounce: product.price_quarter_ounce, discounted_price_quarter_ounce: product.discounted_price_quarter_ounce, max_cart_quantity_quarter_ounce: product.max_cart_quantity_quarter_ounce, special_price_quarter_ounce: product.special_price_quarter_ounce }));

        (product.price_two_gram && tempVariantArr.push({ weight: '2g', priceId: 'two_gram', price_two_gram: product.price_two_gram, discounted_price_two_gram: product.discounted_price_two_gram, max_cart_quantity_two_gram: product.max_cart_quantity_two_gram, special_price_two_gram: product.special_price_two_gram }));

        if (tempVariantArr.length > 0 && product.price_each) {
            tempVariantArr.push({ weight: 'ea', priceId: 'each', price_each: product.price_each, discounted_price_each: product.discounted_price_each, max_cart_quantity_each: product.max_cart_quantity_each, special_price_each: product.special_price_each });
        }

        const variant = tempVariantArr.filter(item => variantId == item.priceId)
        return variant[0]
    }

    async fetchCartDetails(variables: any) {
        try {
            const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/carts_api/v1/carts/${variables?.checkoutId}`;
            const config = {
                headers: {
                    "Content-Type": "application/json"
                }
            };
            const response = await axios.get(apiUrl, config);
            if (response.status === 200) {
                const totalData = response.data;
                const cartItems = totalData?.data?.items
                const cart = await this.getProduct(cartItems, totalData?.data?.store_id)
                const allProductData = await Promise.all(cart);
                const finalCartItems = Object.values(cartItems).map((item: any) => {
                    const productId = item?.product_id
                    const variantId = item?.variant_id
                    const quantity = item?.quantity
                    const filterData = allProductData.filter(item => productId == item.product_id)
                    const variant = this.selectedVarient(filterData[0], variantId)
                    return { productId, product: filterData[0], price: variantId, quantity, weight: variant?.weight, variant }
                })
                return ResponseUtils.successResponseHandler(
                    200,
                    "Products list fetched successfully",
                    "data",
                    finalCartItems
                );
            }
        } catch (e) {
            return e;
        }
    }
}