import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { JaneCheckoutGuard } from "src/core/guards/jane-checkout.guard";
import { LoggerService } from "src/modules/logger/logger.service";
import { Constants } from "src/utils/constants";
import { CreatePostCheckoutServiceDto } from "./dto/create-post-checkout-service.dto";
import { UpdatePostCheckoutServiceDto } from "./dto/update-post-checkout-service.dto";
import { PostCheckoutServiceService } from "./post-checkout-service.service";

@Controller({ path: "post-checkout-service", version: Constants.API_VERSION_1 })

export class PostCheckoutServiceController {
    constructor(private readonly service: PostCheckoutServiceService,
        private readonly logger: LoggerService
    ) {
    }

    @Post()
    @UseGuards(JaneCheckoutGuard)
    create(@Body() dto: CreatePostCheckoutServiceDto) {
        this.logger.log('Jane Post Checkout Api hit', dto);
        const newDto = {
            ...dto,
            orderId: dto.cart?.id,
            amount: dto.cart?.amount,
            status: dto.cart?.status,
            customerPhoneNumber: dto.cart?.customer_phone_number,
            customerName: dto.cart?.customer_name,
            storeId: dto.cart?.store_id,
            orderUUID: dto.cart?.uuid
        }
        // JaneCheckoutLogger.log({
        //     level: 'info',
        //     message: 'logging now' + new Date(),
        //     data: dto
        // });
        return this.service.create(newDto);
    }

    @Get()
    //@UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdatePostCheckoutServiceDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
