import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreatePostCheckoutServiceDto } from "./dto/create-post-checkout-service.dto";
import { UpdatePostCheckoutServiceDto } from "./dto/update-post-checkout-service.dto";
import { PostCheckoutService } from "./entities/post-checkout-service.entity";

@EntityRepository(PostCheckoutService)
export class PostCheckoutServiceRepository extends Repository<PostCheckoutService> {
    async createEntity(dto: CreatePostCheckoutServiceDto): Promise<PostCheckoutService | Error> {
        try {
            const {
                cart,
                webhook_event,
                orderId,
                amount,
                status,
                customerPhoneNumber,
                customerName,
                storeId,
                orderUUID

            } = dto;
            const entity = this.create({
                cart,
                webhook_event,
                orderId,
                amount,
                status,
                customerPhoneNumber,
                customerName,
                storeId,
                orderUUID
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PostCheckoutService | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePostCheckoutServiceDto): Promise<PostCheckoutService | Error> {
        try {
            await this.update(id, {
                cart: dto.cart,
                webhook_event: dto.webhook_event,
                orderId: dto.orderId,
                amount: dto.amount,
                status: dto.status,
                customerPhoneNumber: dto.customerPhoneNumber,
                customerName: dto.customerName,
                storeId: dto.storeId,
                orderUUID: dto.orderUUID
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PostCheckoutService[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(PostCheckoutService)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}