import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { TypeOrmModule } from "@nestjs/typeorm";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { UsersRepository } from "src/modules/users/user.repository";
import { DoSpacesServicerovider } from "../../../SpacesModule/SpacesService";
import { DoSpacesService } from "../../../SpacesModule/SpacesService/doSpacesService";
import { ElasticsearchModule } from "@nestjs/elasticsearch";
import { RetailerImageGalleryRepository } from "src/modules/retailer-image-gallery/retailer-image-gallery.repository";
import { RetailerServiceIHeartJaneRepository } from "./retailer-service-iheartjane.repository";
import { RetailerServiceIHeartJaneController } from "./retailer-service-iheartjane.controller";
import { RetailerServiceIHeartJaneService } from "./retailer-service-iheartjane.service";

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([RetailerServiceIHeartJaneRepository, RetailerImageGalleryRepository]),
        ElasticsearchModule.registerAsync({
            useFactory: async () => ({
                node: process.env.ELASTIC_NODE,
                auth: {
                    apiKey: process.env.ELASTIC_API_KEY
                },
                maxRetries: 10,
                requestTimeout: 10000
            })
        })
    ],
    controllers: [RetailerServiceIHeartJaneController],
    providers: [RetailerServiceIHeartJaneService, JwtHelper, DoSpacesService, DoSpacesServicerovider]
})
export class RetailerServiceIHeartJaneModule {
}
