import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { PressReleaseService } from "./press-release.service";
import { CreatePressReleaseDto } from "./dto/create-press-release.dto";
import { UpdatePressReleaseDto } from "./dto/update-press-release.dto";

@Controller({ path: "press-release", version: Constants.API_VERSION_1 })

export class PressReleaseController {
    constructor(private readonly service: PressReleaseService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    create(@Body() dto: CreatePressReleaseDto,
           @UploadedFiles() files: {
               image: UploadedMulterFileI
           }) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get("/filter")
    filterPressRelease(
      @Query("page") page: number,
      @Query("limit") limit: number,
      @Query("category") category?: string
    ) {
        return this.service.filterPressRelease(
          page,
          limit,
          category
        );
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    update(
      @Param("id") id: string,
      @Body() dto: UpdatePressReleaseDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI
      }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
