import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateRetailerImageGalleryDto } from "./dto/create-retailer-image-gallery.dto";
import { UpdateRetailerImageGalleryDto } from "./dto/update-retailer-image-gallery.dto";
import { RetailerImageGalleryEntity } from "./entities/retailer-image-gallery.entity";

@EntityRepository(RetailerImageGalleryEntity)
export class RetailerImageGalleryRepository extends Repository<RetailerImageGalleryEntity> {

    async createEntity(dto: CreateRetailerImageGalleryDto): Promise<RetailerImageGalleryEntity | Error> {
        try {
            const { retailerId, retailerName, image } = dto;
            const entity = this.create({
                retailerId,
                retailerName,
                image
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<RetailerImageGalleryEntity[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<RetailerImageGalleryEntity | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateRetailerImageGalleryDto): Promise<RetailerImageGalleryEntity | Error> {
        try {
            await this.update(id, {
                retailerId: dto.retailerId,
                retailerName: dto.retailerName,
                image: dto.image
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(RetailerImageGalleryEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    // async findByName(name: string): Promise<RetailerImageGalleryEntity[] | Error> {
    //     try {
    //         return await this.find({
    //             where: { 
    //                 name: name, 
    //                 isDeleted: false 
    //             }
    //         });
    //     }
    //     catch (e) {
    //         return e;
    //     }
    // }

    async deleteImage(images : any): Promise<any | Error> {
        try {
            await getConnection()
                .createQueryBuilder()
                .delete()
                .from(RetailerImageGalleryEntity)
                .where("image IN (:image)", { image: images })
                .execute();
        }
        catch (e) {
            return e;
        }
    }

    async deleteImageByRetailerId(id : any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
            .createQueryBuilder()
            .delete()
            .from(RetailerImageGalleryEntity)
            .where("retailerId = :retailerId", { retailerId : id })
            .execute();
        if(deleteResult.affected > 0) {
            return true;
        }
        return false;
        }
        catch (e) {
            return e;
        }
    }
}