import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { ShopDealsPageCmsRepository } from "./shop-deals-page-cms.repository";
import { UpdateShopDealsPageCmsDto } from "./dto/update-shop-deals-page-cms.dto";
import { ShopDealsPageCms } from "./entities/shop-deals-page-cms.entity";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Injectable()
export class ShopDealsPageCmsService {
    constructor(
      @InjectRepository(ShopDealsPageCmsRepository)
      private readonly repository: ShopDealsPageCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateShopDealsPageCmsDto,
      files: {
          shopDealSectionOneBackgroundImage: UploadedMulterFileI,
          shopDealBannerOneImage: UploadedMulterFileI,
          shopDealBannerTwoDesktopImage: UploadedMulterFileI,
          shopDealBannerTwoMobileImage: UploadedMulterFileI,
          shopDealBannerThreeImage: UploadedMulterFileI,
          shopDealFirstPurchaseBackgoundImage: UploadedMulterFileI,
      }
    ): Promise<ShopDealsPageCms | Error> {
        if (files && files.shopDealSectionOneBackgroundImage) {
            const shopDealSectionOneBackgroundImage: any = await this.doSpaceService.uploadFile(files.shopDealSectionOneBackgroundImage[0], "ShopDealsPageCMS/");
            dto.shopDealSectionOneBackgroundImage = shopDealSectionOneBackgroundImage;
        }

        if (files && files.shopDealBannerOneImage) {
            const shopDealBannerOneImage: any = await this.doSpaceService.uploadFile(files.shopDealBannerOneImage[0], "ShopDealsPageCMS/");
            dto.shopDealBannerOneImage = shopDealBannerOneImage;
        }

        if (files && files.shopDealBannerTwoDesktopImage) {
            const shopDealBannerTwoDesktopImage: any = await this.doSpaceService.uploadFile(files.shopDealBannerTwoDesktopImage[0], "ShopDealsPageCMS/");
            dto.shopDealBannerTwoDesktopImage = shopDealBannerTwoDesktopImage;
        }

        if (files && files.shopDealBannerTwoMobileImage) {
            const shopDealBannerTwoMobileImage: any = await this.doSpaceService.uploadFile(files.shopDealBannerTwoMobileImage[0], "ShopDealsPageCMS/");
            dto.shopDealBannerTwoMobileImage = shopDealBannerTwoMobileImage;
        }

        if (files && files.shopDealBannerThreeImage) {
            const shopDealBannerThreeImage: any = await this.doSpaceService.uploadFile(files.shopDealBannerThreeImage[0], "ShopDealsPageCMS/");
            dto.shopDealBannerThreeImage = shopDealBannerThreeImage;
        }

        if (files && files.shopDealFirstPurchaseBackgoundImage) {
            const shopDealFirstPurchaseBackgoundImage: any = await this.doSpaceService.uploadFile(files.shopDealFirstPurchaseBackgoundImage[0], "ShopDealsPageCMS/");
            dto.shopDealFirstPurchaseBackgoundImage = shopDealFirstPurchaseBackgoundImage;
        }

        // const isExists = await this.repository.find({ isDeleted: false });
        const isExists = await this.repository.find({
            isDeleted: false
        });
        if (dto.isDefault) {
            // Retrieve all entities
            const entities = await this.repository.find();

            // Update the isDefault property for each entity
            for (const entity of entities) {
                const updateData = await this.repository.update(entity.id, { isDefault: false });
            }
            ;
        }
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ShopDealsPageCms[] | Error> {
        const data = await this.repository.find({
            isDeleted: false
        });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}