import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateStayEnlightenedDto } from "./dto/create-stay-enlightened.dto";
import { UpdateStayEnlightenedDto } from "./dto/update-stay-enlightened.dto";
import { StayEnlightened } from "./entities/stay-enlightened.entity";

@EntityRepository(StayEnlightened)
export class StayEnlightenedRepository extends Repository<StayEnlightened> {
    async createEntity(dto: CreateStayEnlightenedDto): Promise<StayEnlightened | Error> {
        try {
            const {
                email
            } = dto;
            const entity = this.create({
                email
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByEmailAddress(email: string): Promise<StayEnlightened | Error> {
        try {
            return await this.findOne({
                where: { email: email, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<StayEnlightened | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateStayEnlightenedDto): Promise<StayEnlightened | Error> {
        try {
            await this.update(id, {
                email: dto.email
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<StayEnlightened[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(StayEnlightened)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}